@@ -1,5 +1,5 @@
 /* serpent.c - Implementation of the Serpent encryption algorithm.
- *	Copyright (C) 2003 Free Software Foundation, Inc.
+ *	Copyright (C) 2003, 2004, 2005 Free Software Foundation, Inc.
  *
  * This file is part of Libgcrypt.
  *
@@ -907,7 +907,7 @@ serpent_test (void)
       },
       {
 	0
-      },
+      }
     };
 
   for (i = 0; test_data[i].key_length; i++)
@@ -960,19 +960,19 @@ gcry_cipher_spec_t _gcry_cipher_spec_serpent128 =
   {
     "SERPENT128", cipher_spec_serpent128_aliases, NULL, 16, 128,
     sizeof (serpent_context_t),
-    serpent_setkey, serpent_encrypt, serpent_decrypt,
+    serpent_setkey, serpent_encrypt, serpent_decrypt, NULL, NULL
   };
 
 gcry_cipher_spec_t _gcry_cipher_spec_serpent192 =
   {
     "SERPENT192", NULL, NULL, 16, 192,
     sizeof (serpent_context_t),
-    serpent_setkey, serpent_encrypt, serpent_decrypt,
+    serpent_setkey, serpent_encrypt, serpent_decrypt, NULL, NULL
   };
 
 gcry_cipher_spec_t _gcry_cipher_spec_serpent256 =
   {
     "SERPENT256", NULL, NULL, 16, 256,
     sizeof (serpent_context_t),
-    serpent_setkey, serpent_encrypt, serpent_decrypt,
+    serpent_setkey, serpent_encrypt, serpent_decrypt, NULL, NULL
   };
