@@ -75,16 +75,13 @@ _gcry_mpi_alloc_secure( unsigned nlimbs )
 mpi_ptr_t
 _gcry_mpi_alloc_limb_space( unsigned int nlimbs, int secure )
 {
-    size_t len = nlimbs * sizeof(mpi_limb_t);
-    mpi_ptr_t p = NULL;
+    mpi_ptr_t p;
+    size_t len;
 
-    if (!nlimbs)
-      {
-        p = secure? gcry_xmalloc_secure( 1 ) : gcry_xmalloc( 1 );
-        *p = 0;
-      }
-    else
-      p = secure? gcry_xmalloc_secure( len ) : gcry_xmalloc( len );
+    len = (nlimbs ? nlimbs : 1) * sizeof (mpi_limb_t);
+    p = secure ? gcry_xmalloc_secure (len) : gcry_xmalloc (len);
+    if (! nlimbs)
+      *p = 0;
 
     return p;
 }
@@ -118,17 +115,29 @@ _gcry_mpi_assign_limb_space( gcry_mpi_t a, mpi_ptr_t ap, unsigned int nlimbs )
 
 
 /****************
- * Resize the array of A to NLIMBS. the additional space is cleared
- * (set to 0) [done by gcry_realloc()]
+ * Resize the array of A to NLIMBS.  The additional space is cleared
+ * (set to 0).
  */
 void
 _gcry_mpi_resize (gcry_mpi_t a, unsigned nlimbs)
 {
+  size_t i;
+
   if (nlimbs <= a->alloced)
-    return; /* no need to do it */
+    {
+      /* We only need to clear the new space (this is a nop if the
+         limb space is already of the correct size. */
+      for (i=a->nlimbs; i < a->alloced; i++)
+        a->d[i] = 0;
+      return; 
+    }
 
   if (a->d)
-    a->d = gcry_xrealloc (a->d, nlimbs * sizeof (mpi_limb_t));
+    {
+      a->d = gcry_xrealloc (a->d, nlimbs * sizeof (mpi_limb_t));
+      for (i=a->alloced; i < nlimbs; i++)
+        a->d[i] = 0;
+    }
   else
     {
       if (a->flags & 1)
@@ -380,19 +389,19 @@ void
 gcry_mpi_randomize( gcry_mpi_t w,
 		    unsigned int nbits, enum gcry_random_level level )
 {
-  char *p;
+  unsigned char *p;
   size_t nbytes = (nbits+7)/8;
   
   if (level == GCRY_WEAK_RANDOM)
     {
-      p = mpi_is_secure(w) ? gcry_xmalloc (nbytes)
-                           : gcry_xmalloc_secure (nbytes);
+      p = mpi_is_secure(w) ? gcry_xmalloc_secure (nbytes)
+                           : gcry_xmalloc (nbytes);
       gcry_create_nonce (p, nbytes);
     }
   else
     {
-      p = mpi_is_secure(w) ? gcry_random_bytes (nbytes, level)
-                           : gcry_random_bytes_secure (nbytes, level);
+      p = mpi_is_secure(w) ? gcry_random_bytes_secure (nbytes, level)
+                           : gcry_random_bytes (nbytes, level);
     }
   _gcry_mpi_set_buffer( w, p, nbytes, 0 );
   gcry_free (p);
@@ -427,5 +436,7 @@ gcry_mpi_get_flag( gcry_mpi_t a, enum gcry_mpi_flag flag )
       case GCRYMPI_FLAG_OPAQUE: return (a->flags & 4);
       default: log_bug("invalid flag value\n");
     }
+    /*NOTREACHED*/
+    return 0;
 }
 
